@@ -36,6 +36,7 @@ DEFAULT_ORACLE_CLIENT_CONFIG_DIR = ''
 # DEVELOPMENT OPTIONS
 DEFAULT_READ_PARSED_MAPPINGS_PATH = ''
 DEFAULT_WRITE_PARSED_MAPPINGS_PATH = ''
+DEFAULT_ENFORCE_SQL_QUERY_FILTER_NULL = 'yes'
 
 
 ##############################################################################
@@ -70,6 +71,7 @@ MARIADB = 'MARIADB'
 MSSQL = 'MSSQL'
 ORACLE = 'ORACLE'
 POSTGRESQL = 'POSTGRESQL'
+SQLITE = 'SQLITE'
 
 FILE_SOURCE_TYPES = [CSV, TSV, EXCEL, PARQUET, FEATHER, ORC, STATA, SAS, SPSS, JSON, XML]
 DATA_SOURCE_TYPES = [RDB] + FILE_SOURCE_TYPES
