@@ -13,10 +13,10 @@ import logging
 import sql_metadata
 
 from ..constants import *
-from ..utils import replace_predicates_in_graph, get_repeated_elements_in_list, get_mapping_rule_from_triples_map_id
+from ..utils import *
 from ..mapping.mapping_constants import MAPPINGS_DATAFRAME_COLUMNS, MAPPING_PARSING_QUERY, JOIN_CONDITION_PARSING_QUERY
 from ..mapping.mapping_partitioner import MappingPartitioner
-from ..data_source.relational_database import get_column_datatype
+from ..data_source.relational_database import get_column_datatype, _replace_query_enclosing_characters
 
 
 def _mapping_to_rml(mapping_graph):
@@ -285,6 +285,7 @@ class MappingParser:
         self._get_from_r2_rml()
         self._normalize_mappings()
         self._infer_datatypes()
+        self._enforce_sql_query_filter_null()
 
         self.validate_mappings()
 
@@ -475,7 +476,7 @@ class MappingParser:
         (https://www.w3.org/2001/sw/rdb2rdf/r2rml/#natural-mapping).
         """
 
-        # return if datatype inferring is not enabled in the config
+        # return if datatype inferring is disabled in the config
         if not self.config.infer_sql_datatypes():
             return
 
@@ -521,6 +522,40 @@ class MappingParser:
                         except:
                             pass
 
+    def _enforce_sql_query_filter_null(self):
+        """
+        Adds to rr:sqlQuery provided by the users clauses to filter NULLs. This is necessary due to a Pandas limitation
+        See issue #35 (https://github.com/oeg-upm/Morph-KGC/issues/35).
+        """
+
+        # return if enforcing NULLs filtering in SQL queries is disabled in the config
+        if not self.config.enforce_sql_filter_null():
+            return
+
+        for i, mapping_rule in self.mappings_df.iterrows():
+            if pd.notna(mapping_rule['query']):
+                sql_query = mapping_rule['query']
+                sql_query_metadata = sql_metadata.Parser(sql_query)
+
+                if 'where' in sql_query_metadata.columns_dict:
+                    sql_query = sql_query + ' AND'
+                else:
+                    sql_query = sql_query + ' WHERE'
+
+                inv_column_aliases = {v: k for k, v in sql_query_metadata.columns_aliases.items()}
+                select_columns = []
+                for column in sql_query_metadata.columns_dict['select']:
+                    if column in inv_column_aliases:
+                        select_columns.append(inv_column_aliases[column])
+                    else:
+                        select_columns.append(column)
+
+                for select_column in select_columns:
+                    sql_query = sql_query + ' "' + select_column + '"' + ' IS NOT NULL AND'
+                sql_query = sql_query[:-4]
+
+                self.mappings_df.at[i, 'query'] = sql_query
+
     def validate_mappings(self):
         """
         Checks that the mapping rules in the input DataFrame are valid. If something is wrong in the mappings the
