@@ -26,12 +26,12 @@ def _preprocess_data(dataframe, mapping_rule, references, config):
         if config.get_database_url(mapping_rule['source_name']).lower().startswith(ORACLE.lower()):
             dataframe = normalize_oracle_identifier_casing(dataframe, references)
 
-        # for RDB NULLS are removed on query time, but the dataframe is not converted to str
-        dataframe = dataframe_columns_to_str(dataframe)
+    # data to str
+    dataframe = dataframe.astype(str)
 
-    # remove NULLS for those data formats that do not allow to remove them in reading time
+    # remove NULLS for those data formats that do not allow to remove them at reading time
     if config.apply_na_filter():
-        if mapping_rule['source_type'] in [PARQUET, FEATHER, ORC, STATA, SAS, SPSS, JSON, XML]:
+        if mapping_rule['source_type'] in [RDB, PARQUET, FEATHER, ORC, STATA, SAS, SPSS, JSON, XML]:
             dataframe = remove_null_values_from_dataframe(dataframe, config)
 
     return dataframe
@@ -172,13 +172,13 @@ def _materialize_join_mapping_rule_terms(results_df, mapping_rule, parent_triple
         results_df = _materialize_constant(results_df, parent_triples_map_rule['subject_constant'], termtype=parent_triples_map_rule['subject_termtype'])
     elif pd.notna(parent_triples_map_rule['subject_reference']):
         results_df = _materialize_reference(results_df, parent_triples_map_rule['subject_reference'], config, termtype=parent_triples_map_rule['subject_termtype'], columns_alias='parent_')
-    if pd.notna(mapping_rule['graph_template']):
-        results_df = _materialize_template(results_df, mapping_rule['graph_template'], config, columns_alias='child_')
-    elif pd.notna(mapping_rule['graph_constant']):
-        if pd.notna(mapping_rule['graph_constant'] != R2RML_DEFAULT_GRAPH):
+    if config.get_output_format() == 'N-QUADS':
+        if pd.notna(mapping_rule['graph_template']):
+            results_df = _materialize_template(results_df, mapping_rule['graph_template'], config, columns_alias='child_')
+        elif pd.notna(mapping_rule['graph_constant']):
             results_df = _materialize_constant(results_df, mapping_rule['graph_constant'])
-    elif pd.notna(mapping_rule['graph_reference']):
-        results_df = _materialize_reference(results_df, mapping_rule['graph_reference'], config, termtype=R2RML_IRI, columns_alias='child_')
+        elif pd.notna(mapping_rule['graph_reference']):
+            results_df = _materialize_reference(results_df, mapping_rule['graph_reference'], config, termtype=R2RML_IRI, columns_alias='child_')
 
     return set(results_df['triple'])
 
@@ -207,8 +207,7 @@ def _materialize_mapping_rule_terms(results_df, mapping_rule, config):
         if pd.notna(mapping_rule['graph_template']):
             results_df = _materialize_template(results_df, mapping_rule['graph_template'], config)
         elif pd.notna(mapping_rule['graph_constant']):
-            if config.materialize_default_graph() or mapping_rule['graph_constant'] != R2RML_DEFAULT_GRAPH:
-                results_df = _materialize_constant(results_df, mapping_rule['graph_constant'])
+            results_df = _materialize_constant(results_df, mapping_rule['graph_constant'])
         elif pd.notna(mapping_rule['graph_reference']):
             results_df = _materialize_reference(results_df, mapping_rule['graph_reference'], config, termtype=R2RML_IRI)
 
@@ -258,7 +257,7 @@ def _materialize_mapping_rule(mapping_rule, subject_maps_df, config):
                 parent_result_chunks = get_file_data(config, parent_triples_map_rule, parent_references)
 
             for parent_query_results_chunk_df in parent_result_chunks:
-                parent_query_results_chunk_df = _preprocess_data(parent_query_results_chunk_df, mapping_rule, references, config)
+                parent_query_results_chunk_df = _preprocess_data(parent_query_results_chunk_df, mapping_rule, parent_references, config)
                 parent_query_results_chunk_df = parent_query_results_chunk_df.add_prefix('parent_')
                 merged_query_results_chunk_df = _merge_results_chunks(query_results_chunk_df,
                                                                       parent_query_results_chunk_df, mapping_rule)
